@@ -12,9 +12,10 @@ import sys
 import logging
 
 import artella
-import artella.dcc as dcc
+from artella import api
+from artella import dcc
 import artella.loader as loader
-from artella.core import plugin, utils, qtutils
+from artella.core import plugin, utils, qtutils, dccplugin
 
 logger = logging.getLogger('artella')
 
@@ -32,7 +33,7 @@ class UninstallerPlugin(plugin.ArtellaPlugin, object):
         if not os.path.isdir(artella_path):
             msg = 'Artella folder "{}" does not exists!'.format(artella_path)
             if show_dialogs:
-                artella.DccPlugin().show_warning_message(text=msg)
+                api.show_warning_message(text=msg)
             else:
                 logger.warning(msg)
             return False
@@ -44,13 +45,13 @@ class UninstallerPlugin(plugin.ArtellaPlugin, object):
         if not res:
             return False
 
-        do_remove_install_folder = not artella.DccPlugin().dev
+        do_remove_install_folder = not dccplugin.DccPlugin().dev
 
         valid_uninstall = self._uninstall(artella_path)
         if not valid_uninstall:
             msg = 'Artella uninstall process was not completed!'.format(artella_path)
             if show_dialogs:
-                artella.DccPlugin().show_error_message(text=msg)
+                api.show_error_message(text=msg)
             else:
                 logger.error(msg)
             return False
@@ -75,6 +76,12 @@ class UninstallerPlugin(plugin.ArtellaPlugin, object):
                 logger.info(msg)
             utils.open_folder(os.path.dirname(artella_path))
 
+        # Remove specific DCC install folder if exists
+        root_dcc_install_dir = os.path.dirname(os.path.dirname(os.path.dirname(artella_path)))
+        dcc_install_dir = os.path.join(root_dcc_install_dir, dcc.name())
+        if os.path.isdir(dcc_install_dir):
+            utils.delete_folder(dcc_install_dir)
+
         # Cleanup artella directories from
         artella_dir = os.path.dirname(artella_path)
         sys_paths = [artella_path, artella_dir, utils.clean_path(artella_path), utils.clean_path(artella_dir)]
@@ -93,4 +100,4 @@ class UninstallerPlugin(plugin.ArtellaPlugin, object):
         return True
 
     def _uninstall(self, artella_path):
-        return True
\ No newline at end of file
+        return True
